@@ -1,5 +1,5 @@
 from youtubesearchpython.__future__.search import Search, VideosSearch, ChannelsSearch, PlaylistsSearch, CustomSearch, ChannelSearch
-from youtubesearchpython.__future__.extras import Video, Playlist, Suggestions, Hashtag, Comments
+from youtubesearchpython.__future__.extras import Video, Playlist, Suggestions, Hashtag, Comments, Transcript, Channel
 from youtubesearchpython.__future__.streamurlfetcher import StreamURLFetcher
 from youtubesearchpython.core.utils import *
 from youtubesearchpython.core.constants import *
